==> hestia-earth-models-0.5.1.tar.gz: hestia-earth-models-0.5.1/hestia_earth/models/stehfestBouwman2006GisImplementation/noxToAirAllOrigins.py <==
from hestia_earth.schema import EmissionMethodTier
from hestia_earth.utils.lookup import download_lookup, get_table_value
from hestia_earth.utils.tools import list_sum, safe_parse_float

from hestia_earth.models.log import logger
from hestia_earth.models.utils.emission import _new_emission
from hestia_earth.models.utils.input import get_total_nitrogen
from hestia_earth.models.utils.product import residue_nitrogen
from . import MODEL

TERM_ID = 'noxToAirAllOrigins'


def _should_run(cycle: dict):
    country_id = cycle.get('site', {}).get('country', {}).get('@id')

    residue = residue_nitrogen(cycle.get('products', []))
    logger.debug('residue, value=%s', residue)

    N_total = list_sum(get_total_nitrogen(cycle.get('inputs', [])) + [residue])
    logger.debug('N_total, value=%s', N_total)

    should_run = country_id is not None and N_total > 0
    logger.info('model=%s, term=%s, should_run=%s', MODEL, TERM_ID, should_run)
    return should_run, country_id, N_total, residue


def _get_value(country_id: str, N_total: float):
    lookup = download_lookup('region.csv', True)
    value = safe_parse_float(get_table_value(lookup, 'termid', country_id, 'ef_nox'))
    value = value * N_total
    logger.info('model=%s, term=%s, value=%s', MODEL, TERM_ID, value)
    return value


def _emission(value: float):
    logger.info('model=%s, term=%s, value=%s', MODEL, TERM_ID, value)
    emission = _new_emission(TERM_ID, MODEL)
    emission['value'] = [value]
    emission['methodTier'] = EmissionMethodTier.TIER_1.value
    return emission


def _run(country_id: str, N_total: float):
    value = _get_value(country_id, N_total)
    return [_emission(value)]


def run(cycle: dict):
    should_run, country_id, N_total, *args = _should_run(cycle)
    return _run(country_id, N_total) if should_run else []

==> hestia-earth-models-0.7.1.tar.gz: hestia-earth-models-0.7.1/hestia_earth/models/stehfestBouwman2006GisImplementation/noxToAirAllOrigins.py <==
from hestia_earth.schema import EmissionMethodTier, EmissionStatsDefinition
from hestia_earth.utils.lookup import download_lookup, get_table_value
from hestia_earth.utils.tools import list_sum, safe_parse_float

from hestia_earth.models.log import logger
from hestia_earth.models.utils.emission import _new_emission
from hestia_earth.models.utils.input import get_total_nitrogen
from hestia_earth.models.utils.product import residue_nitrogen
from hestia_earth.models.utils.cycle import valid_site_type
from . import MODEL

TERM_ID = 'noxToAirAllOrigins'


def _should_run(cycle: dict):
    country_id = cycle.get('site', {}).get('country', {}).get('@id')

    residue = residue_nitrogen(cycle.get('products', []))
    logger.debug('residue, value=%s', residue)

    N_total = list_sum(get_total_nitrogen(cycle.get('inputs', [])) + [residue])
    logger.debug('N_total, value=%s', N_total)

    should_run = valid_site_type(cycle) and country_id is not None and N_total > 0
    logger.info('model=%s, term=%s, should_run=%s', MODEL, TERM_ID, should_run)
    return should_run, country_id, N_total, residue


def _get_value(country_id: str, N_total: float):
    lookup = download_lookup('region.csv', True)
    value = safe_parse_float(get_table_value(lookup, 'termid', country_id, 'ef_nox'))
    value = value * N_total
    logger.info('model=%s, term=%s, value=%s', MODEL, TERM_ID, value)
    return value


def _emission(value: float):
    logger.info('model=%s, term=%s, value=%s', MODEL, TERM_ID, value)
    emission = _new_emission(TERM_ID, MODEL)
    emission['value'] = [value]
    emission['methodTier'] = EmissionMethodTier.TIER_1.value
    emission['statsDefinition'] = EmissionStatsDefinition.MODELLED.value
    return emission


def _run(country_id: str, N_total: float):
    value = _get_value(country_id, N_total)
    return [_emission(value)]


def run(cycle: dict):
    should_run, country_id, N_total, *args = _should_run(cycle)
    return _run(country_id, N_total) if should_run else []
